@@ -38,7 +38,7 @@ impl Client {
     /// ```no_run
     /// # extern crate tokio; use anyhow::Result; use std::str::FromStr;
     /// # use safe_network::client::utils::test_utils::read_network_conn_info;
-    /// use safe_network::client::Client;
+    /// use safe_network::client::{Client, DEFAULT_QUERY_TIMEOUT};
     /// use safe_network::types::{ Keypair, Token, MapAction, MapPermissionSet, MapSeqValue, MapSeqEntries};
     /// use rand::rngs::OsRng;
     /// use std::collections::BTreeMap;
@@ -48,7 +48,7 @@ impl Client {
     /// let id = Keypair::new_ed25519(&mut OsRng);
 
     /// # let bootstrap_contacts = Some(read_network_conn_info()?);
-    /// let mut client = Client::new(Some(id), None, bootstrap_contacts).await?;
+    /// let mut client = Client::new(Some(id), None, bootstrap_contacts, DEFAULT_QUERY_TIMEOUT).await?;
     /// # let initial_balance = Token::from_str("100")?; client.trigger_simulated_farming_payout(initial_balance).await?;
     /// let name = XorName::random();
     /// let tag = 15001;
@@ -92,7 +92,7 @@ impl Client {
     /// ```no_run
     /// # extern crate tokio; use anyhow::Result; use std::str::FromStr;
     /// # use safe_network::client::utils::test_utils::read_network_conn_info;
-    /// use safe_network::client::Client;
+    /// use safe_network::client::{Client, DEFAULT_QUERY_TIMEOUT};
     /// use safe_network::types::{ Keypair, Token, MapAction, MapPermissionSet, MapUnseqEntries};
     /// use rand::rngs::OsRng;
     /// use std::collections::BTreeMap;
@@ -102,7 +102,7 @@ impl Client {
     /// let id = Keypair::new_ed25519(&mut OsRng);
 
     /// # let bootstrap_contacts = Some(read_network_conn_info()?);
-    /// let mut client = Client::new(Some(id), None, bootstrap_contacts).await?;
+    /// let mut client = Client::new(Some(id), None, bootstrap_contacts, DEFAULT_QUERY_TIMEOUT).await?;
     /// # let initial_balance = Token::from_str("100")?; client.trigger_simulated_farming_payout(initial_balance).await?;
     /// let name = XorName::random();
     /// let tag = 15001;
@@ -147,7 +147,7 @@ impl Client {
     /// ```no_run
     /// # extern crate tokio; use anyhow::Result; use std::str::FromStr;
     /// # use safe_network::client::utils::test_utils::read_network_conn_info;
-    /// use safe_network::client::Client;
+    /// use safe_network::client::{Client, DEFAULT_QUERY_TIMEOUT};
     /// use safe_network::types::{ Keypair, Token, MapAction, MapPermissionSet, MapUnseqEntries};
     /// use rand::rngs::OsRng;
     /// use std::collections::BTreeMap;
@@ -157,7 +157,7 @@ impl Client {
     /// let id = Keypair::new_ed25519(&mut OsRng);
 
     /// # let bootstrap_contacts = Some(read_network_conn_info()?);
-    /// let mut client = Client::new(Some(id), None, bootstrap_contacts).await?;
+    /// let mut client = Client::new(Some(id), None, bootstrap_contacts, DEFAULT_QUERY_TIMEOUT).await?;
     /// # let initial_balance = Token::from_str("100")?; client.trigger_simulated_farming_payout(initial_balance).await?;
     /// let name = XorName::random();
     /// let tag = 15001;
@@ -235,7 +235,7 @@ impl Client {
     /// ```no_run
     /// # extern crate tokio; use anyhow::Result; use std::str::FromStr;
     /// # use safe_network::client::utils::test_utils::read_network_conn_info;
-    /// use safe_network::client::Client;
+    /// use safe_network::client::{Client, DEFAULT_QUERY_TIMEOUT};
     /// use safe_network::types::{ Keypair, Token, MapAction, MapPermissionSet, MapUnseqEntries};
     /// use std::collections::BTreeMap;
     /// use xor_name::XorName;
@@ -245,7 +245,7 @@ impl Client {
     /// let id = Keypair::new_ed25519(&mut OsRng);
 
     /// # let bootstrap_contacts = Some(read_network_conn_info()?);
-    /// let mut client = Client::new(Some(id), None, bootstrap_contacts).await?;
+    /// let mut client = Client::new(Some(id), None, bootstrap_contacts, DEFAULT_QUERY_TIMEOUT).await?;
     /// # let initial_balance = Token::from_str("100")?; client.trigger_simulated_farming_payout(initial_balance).await?;
     /// let name = XorName::random();
     /// let tag = 15001;
@@ -283,7 +283,7 @@ impl Client {
     /// ```no_run
     /// # extern crate tokio; use anyhow::Result; use std::str::FromStr;
     /// # use safe_network::client::utils::test_utils::read_network_conn_info;
-    /// use safe_network::client::Client;
+    /// use safe_network::client::{Client, DEFAULT_QUERY_TIMEOUT};
     /// use safe_network::types::{ Keypair, Token, MapAction, MapValue, MapPermissionSet, MapUnseqEntries};
     /// use std::collections::BTreeMap;
     /// use xor_name::XorName;
@@ -293,7 +293,7 @@ impl Client {
     /// let id = Keypair::new_ed25519(&mut OsRng);
 
     /// # let bootstrap_contacts = Some(read_network_conn_info()?);
-    /// let mut client = Client::new(Some(id), None, bootstrap_contacts).await?;
+    /// let mut client = Client::new(Some(id), None, bootstrap_contacts, DEFAULT_QUERY_TIMEOUT).await?;
     /// # let initial_balance = Token::from_str("100")?; client.trigger_simulated_farming_payout(initial_balance).await?;
     /// let name = XorName::random();
     /// let tag = 15001;
@@ -353,7 +353,7 @@ impl Client {
     /// ```no_run
     /// # extern crate tokio; use anyhow::Result; use std::str::FromStr;
     /// # use safe_network::client::utils::test_utils::read_network_conn_info;
-    /// use safe_network::client::Client;
+    /// use safe_network::client::{Client, DEFAULT_QUERY_TIMEOUT};
     /// use safe_network::types::{ Keypair, Token, MapAction, MapPermissionSet, MapUnseqEntries};
     /// use rand::rngs::OsRng;
     /// use std::collections::BTreeMap;
@@ -363,7 +363,7 @@ impl Client {
     /// let id = Keypair::new_ed25519(&mut OsRng);
 
     /// # let bootstrap_contacts = Some(read_network_conn_info()?);
-    /// let mut client = Client::new(Some(id), None, bootstrap_contacts).await?;
+    /// let mut client = Client::new(Some(id), None, bootstrap_contacts, DEFAULT_QUERY_TIMEOUT).await?;
     /// # let initial_balance = Token::from_str("100")?; client.trigger_simulated_farming_payout(initial_balance).await?;
     /// let name = XorName::random();
     /// let tag = 15001;
@@ -789,7 +789,7 @@ mod tests {
     // 2. Try getting the data object. It should bail
     #[tokio::test]
     pub async fn del_seq_map_test() -> Result<()> {
-        let client = create_test_client().await?;
+        let mut client = create_test_client().await?;
         let name = XorName(rand::random());
         let tag = 15001;
         let mapref = MapAddress::Seq { name, tag };
@@ -799,6 +799,7 @@ mod tests {
 
         client.delete_map(mapref).await?;
 
+        client.query_timeout = Duration::from_secs(5); // override with a short timeout
         let mut res = client.get_map(address).await;
         while res.is_ok() {
             tokio::time::sleep(Duration::from_millis(200)).await;
@@ -807,10 +808,7 @@ mod tests {
         }
 
         match res {
-            Err(Error::ErrorMessage {
-                source: ErrorMessage::DataNotFound(_),
-                ..
-            }) => (),
+            Err(Error::NoResponse) => (),
             _ => bail!("Unexpected success"),
         }
         Ok(())
@@ -820,7 +818,7 @@ mod tests {
     // 2. Try getting the data object. It should bail
     #[tokio::test]
     pub async fn del_unseq_map_test() -> Result<()> {
-        let client = create_test_client().await?;
+        let mut client = create_test_client().await?;
         let name = XorName(rand::random());
         let tag = 15001;
         let mapref = MapAddress::Unseq { name, tag };
@@ -830,6 +828,7 @@ mod tests {
 
         client.delete_map(mapref).await?;
 
+        client.query_timeout = Duration::from_secs(5); // override with a short timeout
         let mut res = client.get_map(address).await;
         while res.is_ok() {
             // Keep trying until it fails
@@ -837,10 +836,7 @@ mod tests {
         }
 
         match res {
-            Err(Error::ErrorMessage {
-                source: ErrorMessage::DataNotFound(_),
-                ..
-            }) => (),
+            Err(Error::NoResponse) => (),
             _ => bail!("Unexpected success"),
         }
 
@@ -897,10 +893,7 @@ mod tests {
 
         let res = client.get_map_shell(address).await;
         match res {
-            Err(Error::ErrorMessage {
-                source: ErrorMessage::DataNotFound(_),
-                ..
-            }) => (),
+            Err(Error::NoResponse) => (),
             Ok(data) => bail!(
                 "Unexpected Success: Validating owners should fail.  Data received : {:?}",
                 data
