@@ -7,7 +7,7 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use super::read_network_conn_info;
-use crate::client::Client;
+use crate::client::{Client, DEFAULT_QUERY_TIMEOUT};
 use crate::types::{Keypair, Token};
 use crate::{retry_loop, retry_loop_for_pattern};
 use anyhow::Result;
@@ -40,7 +40,13 @@ pub async fn create_test_client() -> Result<Client> {
 pub async fn create_test_client_with(optional_keypair: Option<Keypair>) -> Result<Client> {
     init_logger();
     let contact_info = read_network_conn_info()?;
-    let client = Client::new(optional_keypair.clone(), None, Some(contact_info)).await?;
+    let client = Client::new(
+        optional_keypair.clone(),
+        None,
+        Some(contact_info),
+        DEFAULT_QUERY_TIMEOUT,
+    )
+    .await?;
 
     if optional_keypair.is_none() {
         // get history, will only be Ok when we have _some_ history, aka test tokens
