@@ -100,7 +100,6 @@ impl Wallet {
 
     /// Mutates state.
     pub fn apply_credit(&mut self, credit: Credit) -> Result<()> {
-        trace!("Applying credit of {:?} to {:?}", credit, self.id());
         if self.id.public_key() == credit.recipient() {
             match self.balance.checked_add(credit.amount) {
                 Some(amount) => self.balance = amount,
@@ -116,8 +115,6 @@ impl Wallet {
     /// Test-helper API to simulate Client Transfers.
     #[cfg(feature = "simulated-payouts")]
     pub fn simulated_credit(&mut self, credit: Credit) -> Result<()> {
-        debug!("Wallet simulated credit");
-
         if self.id.public_key() == credit.recipient() {
             match self.balance.checked_add(credit.amount) {
                 Some(amount) => self.balance = amount,
